<?php
/*
================================================================================================
Ecclesiastical - functions.php
================================================================================================
This is the most generic template file in a WordPress theme and is one of the two required files 
for a theme (the other being template-tags.php). This file is used to maintain the main 
functionality and features for this theme. The second file is the template-tags.php that contains 
the extra functions and features.

@package        Ecclesiastical WordPress Theme
@copyright      Copyright (C) 2016. Benjamin Lu
@license        GNU General Public License v2 or later (http://www.gnu.org/licenses/gpl-2.0.html)
@author         Benjamin Lu (http://lumiathemes.com/)
================================================================================================
*/

/*
================================================================================================
Table of Content
================================================================================================
 1.0 - Content Width
 2.0 - Enqueue Styles and Scripts
 3.0 - Theme Setup
 4.0 - Register Sidebars
 5.0 - Required Files
================================================================================================
*/

/*
================================================================================================
 1.0 - Content Width
================================================================================================
*/
function ecclesiastical_content_width() {
    $GLOBALS['content_width'] = apply_filters('ecclesiastical_content_width', 850);
}
add_action('after_setup_theme', 'ecclesiastical_content_width', 0);

/*
================================================================================================
 2.0 - Enqueue Styles and Scripts
================================================================================================
*/
function ecclesiastical_enqueue_scripts_setup() {
    // Enable and Activate the main stylesheet for Ecclesiastical.
    wp_enqueue_style('ecclesiastical-style', get_stylesheet_uri());
    
    // Enable and Activate Google Fonts (Sanchez and Open Sans) Locally for Ecclesiastical.
    wp_enqueue_style('ecclesiastical-google-fonts', get_template_directory_uri() . '/extras/fonts/custom-fonts.css', '20160601', true);
    
    // Enable and Activate Font Awesome for Ecclesiastical
    wp_enqueue_style('font-awesome', get_template_directory_uri() . '/extras/font-awesome/css/font-awesome.css', '20160601', true);
    
    // Enable and Activate Woo FlexSlider 2 for Ecclesiastical
    wp_enqueue_style('ecclesiastical-flexslider-css', get_template_directory_uri() . '/extras/flexslider/flexslider.css', true);
    wp_enqueue_script('ecclesiastical-flexslider-js', get_template_directory_uri() . '//extras/flexslider/jquery.flexslider-min.js', array('jquery'), true);
    wp_enqueue_script('ecclesiastical-flexslider-js-script', get_template_directory_uri() . '/extras/flexslider/flexslider.js', array('jquery'), true);
    
    // Enable and Activate Navigation JavaScript for Ecclesiastical.
    wp_enqueue_script('ecclesiastical-navigation', get_template_directory_uri() . '/js/navigation.js', array('jquery'), '20160601', true);
	wp_localize_script('ecclesiastical-navigation', 'screenReaderText', array(
		'expand'   => '<span class="screen-reader-text">' . __('expand child menu', 'ecclesiastical') . '</span>',
		'collapse' => '<span class="screen-reader-text">' . __('collapse child menu', 'ecclesiastical') . '</span>',
	));
    
    if (is_singular() && comments_open() && get_option('thread_comments')) {
        wp_enqueue_script('comment-reply');
    }
}
add_action('wp_enqueue_scripts', 'ecclesiastical_enqueue_scripts_setup');

/*
================================================================================================
 3.0 - Theme Setup
================================================================================================
*/
function ecclesiastical_theme_setup() {
    // Enable and Activate Add Theme Support (Title Tag) for Ecclesiastical.
    add_theme_support('title-tag');

    // Enable and Activate Add Theme Support (Automatic Feed Links) for Ecclesiastical.
    add_theme_support('automatic-feed-links');

    // Enable and Activat Add Theme Support (HTML5) for Ecclesiastical
    add_theme_support('html5', array(
        'comment-form',
        'comment-list',
        'search-form',
        'caption',
        'gallery',
    ));
    
    // Enable and Activate Featured Images for Ecclesiastical.
    add_theme_support('post-thumbnails');
    add_image_size('ecclesiastical-featured-slider', 1170, 300, true);
    add_image_size('ecclesiastical-small-thumbnail', 200, 200, true);

    register_nav_menus(array(
        'primary'   => esc_html__('Primary Navigation', 'ecclesiastical'),
    ));
}
add_action('after_setup_theme', 'ecclesiastical_theme_setup');

/*
================================================================================================
 4.0 - Register Sidebars
================================================================================================
*/
function ecclesiastical_register_sidebars() {
    register_sidebar(array(
        'name'          => __( 'Primary Sidebar', 'ecclesiastical' ),
        'id'            => 'primary-sidebar',
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget'  => '</aside>',
        'before_title'  => '<h2 class="widget-title">',
        'after_title'   => '</h2>',
    ));
    
    register_sidebar(array(
        'name'          => __( 'Custom Sidebar', 'ecclesiastical' ),
        'id'            => 'custom-sidebar',
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget'  => '</aside>',
        'before_title'  => '<h2 class="widget-title">',
        'after_title'   => '</h2>',
    ));
}
add_action('widgets_init', 'ecclesiastical_register_sidebars');

/*
================================================================================================
 5.0 - Required Files
================================================================================================
*/
require_once(get_template_directory() . '/includes/custom-header.php');
require_once(get_template_directory() . '/includes/customizer.php');
require_once(get_template_directory() . '/includes/template-tags.php');