<?php
/*
================================================================================================
Ecclesiastical - header.php
================================================================================================
This is the most generic template file in a WordPress theme and is one of the two required files 
for a theme (the other footer.php). The header.php template file only displayers the header
section of this theme. This also displays the navigation menu as well.

@package        Ecclesiastical WordPress Theme
@copyright      Copyright (C) 2016. Benjamin Lu
@license        GNU General Public License v2 or later (http://www.gnu.org/licenses/gpl-2.0.html)
@author         Benjamin Lu (http://luminathemes.com/)
================================================================================================
*/
?>
<!DOCTYPE html>
<html <?php language_attributes(); ?>>
    <head>
        <meta charset="<?php bloginfo('charset'); ?>" />
        <meta name="viewport" content="width=device-width, initial-scale=1" />
        <link href="http://gmpg.org/xfn/11" rel="profile" />
        <link href="<?php bloginfo('pingback_url'); ?>" rel="pingback" />
        <?php wp_head(); ?>
    </head>
<body <?php body_class(); ?>>
    <section id="site-container" class="site-container clearfix">
        <?php if (has_nav_menu('primary')) { ?>
            <div id="branding-navigation" class="branding-navigation clearfix">
                <div id="site-branding" class="site-branding">
                    <h1 class="site-title"><a href="<?php echo esc_url(home_url('/')); ?>"><?php bloginfo('name'); ?></a></h1>
                    <h4 class="site-description"><?php bloginfo('description'); ?></h4>
                </div>
                <nav id="site-navigation" class="primary-navigation">
                    <button class="menu-toggle" aria-conrol="primary-menu" aria-expanded="false"><?php esc_html_e('Menu', 'ecclesiastical'); ?></button>
                    <?php wp_nav_menu(array(
                        'theme_location'    => 'primary',
                        'menu_id'           => 'primary-menu',
                        'menu_class'        => 'nav-menu'   
                    )); 
                    ?>
                </nav>
            </div>
        <?php } else { ?>
            <div class="branding">
                <div id="site-branding" class="site-branding">
                    <h1 class="site-title"><a href="<?php echo esc_url(home_url('/')); ?>"><?php bloginfo('name'); ?></a></h1>
                    <h4 class="site-description"><?php bloginfo('description'); ?></h4>
                </div>
            </div>
        <?php } ?>
        <header id="main-header" class="site-header">
            <?php if (get_theme_mod('ecclesiastical_flexslider_options_settings', false) && is_front_page()) { ?>
                <div class="header-image-container">
                    <div class="flexslider">
                        <ul class="slides">

                            <?php
                            // Get all sticky posts, but only sticky posts
                            $args = array(
                                'posts_per_page'    => 5,
                                'cateogry_name'          => 'featured',
                            );
                            $postQuery = get_posts($args);

                            foreach( $postQuery as $post ) : setup_postdata($post);

                                if ( has_post_thumbnail() ) { ?>
                                    <li>
                                        <a href="<?php echo get_permalink(); ?>" title="Go to <?php echo the_title(); ?>" rel="bookmark">
                                            <?php the_post_thumbnail('ecclesiastical-featured-slider'); ?>
                                            <p class="flex-caption"><?php the_title(); ?></p>
                                        </a>
                                    </li>
                                <?php
                                }
                            endforeach;
                            wp_reset_postdata();
                            ?>
                        </ul>
                    </div>
                </div>
            <?php } else if (get_header_image()) { ?>
                <div class="header-image-container">
                    <div class="header-image-container">
                        <img src="<?php header_image(); ?>" width="<?php echo get_custom_header()->width; ?>" height="<?php echo get_custom_header()->height; ?>" alt="">
                    </div>
                </div>
            <?php } else if (!get_header_image()) { ?>
                <div class="header-image-container">
                    <img src="<?php echo esc_url(get_template_directory_uri() . '/images/header-image.jpg'); ?>" />
                </div>
            <?php } ?>
        </header>
        <section id="site-content" class="site-content clearfix">
            <div id="site-wrapper" class="site-wrapper">