<?php
/*
================================================================================================
Ecclesiastical - customizer.php
================================================================================================
This is the most generic template file in a WordPress theme and is one of required files for this
theme. Thie file allows users to change certain color features within the theme, such as, link
colors and body colors.

@package        Ecclesiastical WordPress Theme
@copyright      Copyright (C) 2016. Benjamin Lu
@license        GNU General Public License v2 or later (http://www.gnu.org/licenses/gpl-2.0.html)
@author         Benjamin Lu (http://ninjablume.com/contact/
@since          0.0.1
================================================================================================
*/
function ecclesiastical_customize_register_setup($wp_customize) {
    // This section is mainly for colors for Ecclesiastical
    $wp_customize->add_setting('ecclesiastical_body_link_color', array(
        'capability'        => 'edit_theme_options',
        'default'           => '#1a1a1a',
        'sanitize_callback' => 'sanitize_hex_color',
        'transport'         => 'refresh',
    ));

    $wp_customize->add_setting('ecclesiastical_body_text_color', array(
        'capability'        => 'edit_theme_options',
        'default'           => '#000000',
        'sanitize_callback' => 'sanitize_hex_color',
        'transport'         => 'refresh',
    ));

    $wp_customize->add_setting('ecclesiastical_body_link_color_hover', array(
        'capability'        => 'edit_theme_options',
        'default'           => '#0099cc',
        'sanitize_callback' => 'sanitize_hex_color',
        'transport'         => 'refresh',
    ));

    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'ecclesiastical_body_link_color', array(
        'label'        => esc_html__( 'Link Color', 'ecclesiastical' ),
        'section'    => 'colors',
        'settings'   => 'ecclesiastical_body_link_color',
    )));


    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'ecclesiastical_body_link_color_hover', array(
        'label'        => esc_html__( 'Link Color Hover', 'ecclesiastical' ),
        'section'    => 'colors',
        'settings'   => 'ecclesiastical_body_link_color_hover',
    )));


    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'ecclesiastical_body_text_color', array(
        'label'        => __( 'Body Color', 'ecclesiastical' ),
        'section'    => 'colors',
        'settings'   => 'ecclesiastical_body_text_color',
    )));

    // This section is mainly for the Slider Options
    $wp_customize->add_section('ecclesiastical_flexslider_options_section', array(
        'title'         => esc_html__('Slider Options', 'ecclesiastical'),
        'description'   => __('FlexSlider is disabled by default. Enabled the feature if you wish to use it. You will need to setup a category name <b>Featured</b> and set <b>Featured Image</b> for this to work.', 'ecclesiastical'),
    ));

    $wp_customize->add_setting('ecclesiastical_flexslider_options_settings', array(
        'default'       => '',
        'sanitize_callback' => 'ecclesiastical_sanitize_checkbox',
    ));

    $wp_customize->add_control('ecclesiastical_flexslider_options_control', array(
        'label'         => esc_html__('Enable FlexSlider', 'ecclesiastical'),
        'section'       => 'ecclesiastical_flexslider_options_section',
        'settings'      => 'ecclesiastical_flexslider_options_settings',
        'type'          => 'checkbox'
    ));
}
add_action('customize_register', 'ecclesiastical_customize_register_setup');

function ecclesiastical_custom_colors_css() { ?>
    <style type="text/css">
        body {
            color: <?php echo esc_html(get_theme_mod('ecclesiastical_body_text_color', '#000000')); ?>;
        }

        a {
            color: <?php echo esc_html(get_theme_mod('ecclesiastical_body_link_color', '#1a1a1a')); ?>;
        }

        a:hover {
            color: <?php echo esc_html(get_theme_mod('ecclesiastical_body_link_color_hover', '#0099cc')); ?>
        }
    </style>
<?php
}
add_action('wp_head', 'ecclesiastical_custom_colors_css');

function ecclesiastical_sanitize_checkbox($checked) {
    return((isset($checked) && true == $checked) ? true : false);
}

function ecclessiastical_sanitize_choices($value, $setting) {
    if (in_array($value, array('left', 'right', 'full'))) {
        return $value;
    }
    else {
        return $setting->default;
    }
}